<!-- templates/admin/input_filter.html -->

{% load i18n admin_urls %}

<h3>{% blocktrans with filter_title=title %} Search by {{ filter_title }} {% endblocktrans %}</h3>
<ul>
  <li>
    {% with choices.0 as all_choice %}
    <form method="GET" action="">
        {% for k, v in all_choice.query_parts %}
        <input type="hidden" name="{{ k }}" value="{{ v }}" />
        {% endfor %}
        <input
           type="text"
           value="{{ spec.value|default_if_none:'' }}"
          name="{{ spec.parameter_name }}"/>

        {% if not all_choice.selected %}
      <strong><a href="{{ all_choice.query_string }}">⨉ {% trans 'Remove' %}</a></strong>
    {% endif %}


    </form>
    {% endwith %}
  </li>
</ul>
